#  tests for teradata-15.10.0.21-py27_0 (this is a generated file);
print('===== testing package: teradata-15.10.0.21-py27_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import teradata

udaExec = teradata.UdaExec(appName="HelloWorld", version="1.0",
                           logConsole=False)

#session = udaExec.connect(method="odbc", system="tdprod",
#        username="xxx", password="xxx");

#for row in session.execute("SELECT GetQueryBand()"):
#    print(row)
#  --- run_test.py (end) ---

print('===== teradata-15.10.0.21-py27_0 OK =====');
print("import: 'teradata'")
import teradata

